function p=mkangle2rayp(phase,h,angle,model,p5,p6);
% mkangle2rayp........convert take off angle into ray parameter
%
% call: p=mkangle2rayp(phase,h,angle,model);
%       p=mkangle2rayp(phase,h,angle,vp,vs,rp);
%
%       phase: string containing seismic phase name, like 'P', 'S', 'ScS', 'PKPdf',...
%              The routione does not test whether your ray partameter makes sense for
%              the phase tyou desire!
%           h: hypocentral depth [km]
%       angle: take off angle at source [deg]
%       model: model structure as returned by MKREADND
%
%       vp: p wave velocity at focal depth [km/s]
%       vs: s wave velocity at focal depth [km/s]
%       rp: planetary radius [km]
%
%       VP and VS have to scalar values, the discontinuity-decision depending
%       on the angle has to be made already!
%
% result: p: ray parameter [s/deg]
%
% using VP and VS as input parameter, you don't need to call time wasting MKINTERPMODEL
% here, making everythig quicker.
%
% Martin Knapmeyer, 25.09.2003

%%% a useful constant
radian=pi/180;

%%% what kind of wave do we emit?
starttype=lower(phase(1));

%%% determine velocities from model structure, if necessary
if nargin==4
   %%% determine velocity at source depth (needed for angle-ray parm conversion)
   %%% if h is a discontinuity depth, there will be two velocioty values.
   %%% vp(1) (or vs(1)) will be for above discontinuity, vp(2) (or vs(2)) for below.
   focus=mkinterpmodel(model,h,'simple');
   indy=find(focus.z==h);
   vp=focus.vp(indy);
   vs=focus.vs(indy);
   rp=model.rp;
   
   %%% at a discontinuity, there will be two velocity values.
   %%% use above-value for angle>=90 and below-value for angle<90
   if angle>=90
      whichangle=1;
   else
      whichangle=min(2,length(vp));
   end; % if angle
   
else
   vp=model;
   vs=p5;
   rp=p6;
   whichangle=1; % because of VP and VS being scalar!
end; % if nargin

%%% which velocity is relevant?
switch starttype
   case {'s'}
       v=vs(whichangle);
   case {'p'}
       v=vp(whichangle);
   otherwise
      error(['MKANGLE2RAYP: phase names cannot start with ' starttype]);
end; % switch


%%% the computation
p=radian*sin(angle*radian)*(rp-h)/v;


return;