function angle=mkrayp2angle(phase,h,p,model,p5,p6);
% mkrayp2ngle........convert ray parameter into take off angle
%
% call: angle=mkangle2rayp(phase,h,p,model);
%       angle=mkangle2rayp(phase,h,p,vp,vs,rp);
%
%       phase: string containing seismic phase name, like 'P', 'S', 'ScS', 'PKPdf',...
%              The routione does not test whether your ray partameter makes sense for
%              the phase tyou desire!
%           h: hypocentral depth [km]
%           p: ray parameter [s/deg]
%       model: model structure as returned by MKREADND
%
%       vp: p wave velocity at focal depth [km/s]
%       vs: s wave velocity at focal depth [km/s]
%       rp: planetary radius [km]
%
%       VP and VS have to scalar values, the discontinuity-decision depending
%       on the angle has to be made already!
%
% result: angle: take off angle at source [deg]
%
%         note that upgoing and downgoing rays may have identical ray parameters
%         (horizontal slownesses!)
%
% using VP and VS as input parameter, you don't need to call time wasting MKINTERPMODEL
% here, making everythig quicker.
% 
% This routine is derived fro MKANGLE2RAYP
%
% Martin Knapmeyer, 24.02.2004

%%% a useful constant
radian=pi/180;

%%% what kind of wave do we emit?
starttype=lower(phase(1));

%%% determine velocities from model structure, if necessary
if nargin==4
   %%% determine velocity at source depth (needed for angle-ray parm conversion)
   %%% if h is a discontinuity depth, there will be two velocioty values.
   %%% vp(1) (or vs(1)) will be for above discontinuity, vp(2) (or vs(2)) for below.
   focus=mkinterpmodel(model,h,'simple');
   indy=find(focus.z==h);
   vp=focus.vp(indy);
   vs=focus.vs(indy);
   rp=model.rp;
   
   %%% at a discontinuity, there will be two velocity values.
   %%% use above-value for p<=0 and below-value for p>0
   if p<=0
      whichangle=1;
   else
      whichangle=min(2,length(vp));
   end; % if angle
   
else
   vp=model;
   vs=p5;
   rp=p6;
   whichangle=1; % because of VP and VS being scalar!
end; % if nargin

%%% which velocity is relevant?
switch starttype
   case {'s'}
       v=vs(whichangle);
   case {'p'}
       v=vp(whichangle);
   otherwise
      error(['MKRAYP2ANGLE: phase names cannot start with ' starttype]);
end; % switch


%%% the computation
%p=radian*sin(angle*radian)*(rp-h)/v;
angle=asin(p*v/(radian*(rp-h)))/radian;


return;