function mktouchdis(model,h);
% mktouchdis.........determine ray parameter needed to touch model discontinuities
%
% call: syn=mktouchdis(model,h);
%
%       model: model structure as returned by MKREADND or MKCLR2MODEL
%       h: focal depth in km
%
% result: none
%         routine produces screen output only.
%
% This routine determines the ray parameter needed to reach the depths
% of all standard and non-standard discontinuities defined in MODEL.
% P, S, PKP, SKS, PKIKP, SKIKS phases are used depending on the part of
% the planet in which the discontinuity is.
% Ray Parameters, Epicentral distances, Travel times are determined.
%
% Martin Knapmeyer, 19.03.2004


   
    
%%% complete discontinuity list
%%% the discontinuity names defined here are referred later when searching for appropriate
%%% take off angles. Names are hard-coded in the later parts of the program! (I know it's bad style)
dz=[model.conr model.moho model.d410 model.d520 model.d660 model.cmb model.icb model.dz];
dname=strvcat('conrad',...
              'moho',...
              'olivine alpha beta',...
              'olivine beta gamma',...
              'olivine gamma perovskite',...
              'cmb',...
              'icb',...
              model.dname); % discontinuity names
danz=length(dz); % so many discontinuities


%%% prepare ray diagram
clf;
mkraydiagram(dz,dname,model.rp);
title([model.name ', Source Depth ' num2str(h) 'km']);


%%% loop through discontinuity list
for dnr=1:danz

   if ~isnan(dz(dnr))
      %%% dz is NaN for undefined standard discontinuities

      
      %%%%%% which phases to use
      if (dz(dnr)<=model.cmb)|((isnan(model.cmb))|(isnan(model.icb)))
         %%% discontinuity is within mantle or CMB
         pphase='P';
         sphase='S';
      else
         if (dz(dnr)>model.cmb)&(dz(dnr)<=model.icb)
            %%% discontinuity is within outer core or ICB
            pphase='PKP';
            sphase='SKS';
         else
            if dz(dnr)>model.icb
               %%% discontinuity is within outer core
               pphase='PKIKP';
               sphase='SKIKS';
            end; % if dz(dnr)>model.icb
         end; % if (dz(dnr)>model.cmb)&(dz(dnr)<=model.icb)
      end; % if dz(dnr)<=model.cmb
   
      
      
      %%%%%% carry out computations for appropriate phases
   
      %%% P wave
      %disp(['MKTOUCHDIS: sending ' pphase ' to ' deblank(dname(dnr,:))]);
      %%% P wave ray parameter
      prayp=mkraydepthinv(model.rp-dz(dnr),model.vp,model.rp-model.z)*pi/180;
      %%% compute ray path
      [dist,rx,rz,rt]=mkx4p(pphase,h,prayp,model);
      %%% compute travel time
      tt=mktim4p(pphase,h,prayp,model);
      %%% plot ray
      if (~isnan(dist))&(~isinf(dist))
         mkraydiagram(rx,rz,rt,model.rp,'addlabel');
      end; % if (~isnan(dist))&(~isinf(dist))
      
      %%% write textb output
      disp([deblank(dname(dnr,:)) ' ' num2str(dz(dnr)) 'km ',...
            pphase ': p=' num2str(prayp) 's/deg ',...
            num2str(dist) 'deg, ' mks2hms(tt) ]);
   
      %%% S wave ray parameter
      
   
   
   else
      disp([deblank(dname(dnr,:)) ': undefined ']);
   end; % if ~isnan(dz(dnr))
   
   
   
end; % for dnr

